Exceptions
==========

.. autoexception:: pyfatfs._exceptions::PyFATException
   :members:
   :show-inheritance:

.. autoexception:: pyfatfs._exceptions::NotAnLFNEntryException
   :members:
   :show-inheritance: